@@ -1,6 +1,6 @@
 package Facebook::Graph::Query;
 BEGIN {
-  $Facebook::Graph::Query::VERSION = '0.0705';
+  $Facebook::Graph::Query::VERSION = '1.0000';
 }
 
 use Any::Moose;
@@ -197,7 +197,7 @@ Facebook::Graph::Query - Simple and fast searching and fetching of Facebook data
 
 =head1 VERSION
 
-version 0.0705
+version 1.0000
 
 =head1 SYNOPSIS
 
@@ -206,19 +206,19 @@ version 0.0705
  my $perl_page = $fb->find('16665510298')
     ->include_metadata
     ->request
-    ->to_hashref;
+    ->as_hashref;
  
  my $sarah_bownds = $fb->find('sarahbownds')
     ->select_fields(qw(id name))
     ->request
-    ->to_hashref;
+    ->as_hashref;
 
  # this one would require an access token
  my $new_car_posts = $fb->query
     ->search('car', 'my_news')
     ->where_since('yesterday')
     ->request
-    ->to_hashref;
+    ->as_hashref;
 
 
 =head1 DESCRIPTION
@@ -231,7 +231,7 @@ This module presents a programatic approach to building the queries necessary to
     ->where_since('yesterday')
     ->limit_results(25)
     ->request
-    ->to_hashref;
+    ->as_hashref;
     
 The above query, if you were read it like text, says: "Give me the user ids and full names of all users named Dave that have been created since yesterday, and limit the result set to the first 25."
 
